@@ -6,6 +6,10 @@ test_that(".get_droughtind works", {
   )
   aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON")[1, ])
 
+  temp_loc <- file.path(tempdir(), "mapme.biodiversity")
+  dir.create(temp_loc, showWarnings = FALSE)
+  resource_dir <- system.file("res", package = "mapme.biodiversity")
+  file.copy(resource_dir, temp_loc, recursive = TRUE)
   outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
   tmpdir <- tempdir()
 
